#ifndef NT2_INCLUDE_FUNCTIONS_BITWISE_AND_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_BITWISE_AND_HPP_INCLUDED

#include <nt2/operator/include/functions/bitwise_and.hpp>

#endif
